==> cscec5b-rmat-impl-3.0.1-20221027.035804-32-sources.jar: com/ejianc/business/rmat/bean/ExitDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_detail")
public class ExitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="exit_id")
    private Long exitId; // 退场主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="stop_date")
    private Date stopDate; // 止租日
    @TableField(value="def1")
    private String def1; // 
    @TableField(value="def2")
    private String def2; // 
    @TableField(value="def3")
    private String def3; // 
    @TableField(value="def4")
    private String def4; // 
    @TableField(value="def5")
    private String def5; // 
    @TableField(value="apply_nums")
    private BigDecimal applyNums; // 申请退场数量
    @TableField(value="exit_nums")
    private BigDecimal exitNums; // 本次退场数量
    @TableField(value="exit_nums_sum")
    private BigDecimal exitNumsSum; // 累计退场数量
    @TableField(value="type")
    private Integer type; // 行类型0-物资档案，1-验收，2-申请
    @TableField(value="check_num")
    private BigDecimal checkNum; // 累计进场数量
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_exit_num")
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    @TableField(value="real_exit_num")
    private BigDecimal realExitNum; // 申请退场数量(实物)
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="rent_out_num")
    private BigDecimal rentOutNum; // 计租退场数量
    @TableField(value="real_out_num")
    private BigDecimal realOutNum; // 实物退场数量
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    
    

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getStopDate() {
        return stopDate;
    }

    public void setStopDate(Date stopDate) {
        this.stopDate = stopDate;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }
}

==> cscec5b-rmat-impl-3.0.1-20221122.102656-95-sources.jar: com/ejianc/business/rmat/bean/ExitDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_detail")
public class ExitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="exit_id")
    private Long exitId; // 退场主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="stop_date")
    private Date stopDate; // 止租日
    @TableField(value="def1")
    private String def1; // 
    @TableField(value="def2")
    private String def2; // 
    @TableField(value="def3")
    private String def3; // 
    @TableField(value="def4")
    private String def4; // 
    @TableField(value="def5")
    private String def5; // 
    @TableField(value="apply_nums")
    private BigDecimal applyNums; // 申请退场数量
    @TableField(value="exit_nums")
    private BigDecimal exitNums; // 本次退场数量
    @TableField(value="exit_nums_sum")
    private BigDecimal exitNumsSum; // 累计退场数量
    @TableField(value="type")
    private Integer type; // 行类型0-物资档案，1-验收，2-申请
    @TableField(value="check_num")
    private BigDecimal checkNum; // 累计进场数量
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_exit_num")
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    @TableField(value="real_exit_num")
    private BigDecimal realExitNum; // 申请退场数量(实物)
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="rent_out_num")
    private BigDecimal rentOutNum; // 计租退场数量
    @TableField(value="real_out_num")
    private BigDecimal realOutNum; // 实物退场数量
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    @TableField(value="is_true")
    private Integer isTrue;//是否能编辑  不等于空能编辑
    @TableField(value="apply_detail_id")
    private Long applyDetailId;//退场申请单明细id



    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getStopDate() {
        return stopDate;
    }

    public void setStopDate(Date stopDate) {
        this.stopDate = stopDate;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }
}
